//
// Programmer:    Craig Stuart Sapp <craig@ccrma.stanford.edu>
// Creation Date: Wed Jun 27 16:16:59 PDT 2001
// Last Modified: Thu Jul  5 14:28:53 PDT 2001
// Filename:      ...sig/maint/code/audio/AudioIn/AudioInput.h
// Web Address:   http://sig.sapp.org/include/sig/AudioInput.h
// Documentation: http://sig.sapp.org/doc/classes/AudioInput
// Syntax:        C++ 
//

#ifndef _AUDIOINPUT_H_INCLUDED
#define _AUDIOINPUT_H_INCLUDED

#ifdef VISUAL
   #define AUDIOINPUT  AudioInput_visual
   #include "AudioInput_visual.h"
#elif defined(LINUX)
   #define AUDIOINPUT  AudioInput_linux
   #include "AudioInput_linux.h"
#elif defined(LINUX) && defined(ALSA) && defined(OSS)
   #define AUDIOINPUT  AudioInput_linux
   #include "AudioInput_linux.h"
#elif defined(LINUX) && defined(ALSA) && !defined(OSS)
   #define AUDIOINPUT  AudioInput_alsa
   #include "AudioInput_alsa.h"
#elif defined (LINUX) && defined(OSS) && !defined(ALSA)
   #define AUDIOINPUT  AudioInput_oss
   #include "AudioInput_oss.h"
#elif defined(LINUX)
   #define AUDIOINPUT  AudioInput_oss
   #include "AudioInput_oss.h"
#else
   #define AUDIOINPUT  AudioInput_unsupported
   #include "AudioInput_unsupported.h"
#endif



class AudioInput : protected AUDIOINPUT {
   public:

            AudioInput   (void) { AUDIOINPUT(); }

      void  close        (void) { AUDIOINPUT::close(); }
      int   open         (void) { return AUDIOINPUT::open(); }
      int   open16LSB    (int channels = 1, double samplingrate = 44100.0) {
                            return AUDIOINPUT::open16LSB(channels, samplingrate); 
                         }
      int   is_open      (void) {  return AUDIOINPUT::is_open(); }
      void  read         (uchar* buf, int count) { AUDIOINPUT::read(buf, count); }
      int   getFd        (void) { return AUDIOINPUT::getFd(); }

};



#endif  /* _AUDIOINPUT_H_INCLUDED */



// md5sum: adbc4a4981d4551d1e22e450585a6f09 AudioInput.h [20010708]
