//
// Programmer:    Craig Stuart Sapp <craig@ccrma.stanford.edu>
// Creation Date: Wed Feb  5 19:42:53 PST 1997
// Last Modified: Wed Dec 17 23:54:07 GMT-0800 1997
// Last Modified: Sun Jun 11 13:13:49 PDT 2000 (added setSize() function)
// Last Modified: Fri Aug 18 22:55:33 PDT 2000 (added include of .cpp)
// Last Modified: Sun Feb  4 13:03:13 PST 2001 (added getBase() function)
// Filename:      ...sig/maint/code/base/Block/Block.h
// Web Address:   http://sig.sapp.org/include/sig/Block.h
// Documentation: http://sig.sapp.org/doc/classes/Block
// Syntax:        C++ 
//
// Description:   An array for signal processing.
//

#ifndef _BLOCK_H_INCLUDED
#define _BLOCK_H_INCLUDED


template<class type>
class Block {
   public:
                     Block            (void);
                     Block            (int blockSize);
                     Block            (Block<type>& aBlock);
                     Block            (const type* anArray, int arraySize);
                    ~Block            ();

      type*          getBase          (void);
      int            getSize          (void) const;
      void           zero             (int minIndex = -1, int maxIndex = -1);

      type&          operator[]       (int arrayIndex);
      type           operator[]       (int arrayIndex) const;
      Block<type>&   operator=        (const Block<type>& aBlock);
      Block<type>&   operator+=       (const Block<type>& aBlock);
      Block<type>&   operator-=       (const Block<type>& aBlock);
      Block<type>&   operator*=       (const Block<type>& aBlock);
      Block<type>&   operator/=       (const Block<type>& aBlock);

      Block<type>    operator+        (const Block<type>& aBlock) const;
      Block<type>    operator+        (type aNumber) const;
      Block<type>    operator-        (const Block<type>& aBlock) const;
      Block<type>    operator-        (void) const;
      Block<type>    operator-        (type aNumber) const;
      Block<type>    operator*        (const Block<type>& aBlock) const;
      Block<type>    operator*        (type aNumber) const;
      Block<type>    operator/        (const Block<type>& aBlock) const;
 
      void           setSize          (int aSize);

   protected:
      int            size;
      type          *array;

};

#include "Block.cpp"



#endif  /* _BLOCK_H_INCLUDED */



// md5sum: fccd6e0b47b0794a9ee406e570f0f07c Block.h [20010708]
