//
// Programmer:    Craig Stuart Sapp <craig@ccrma.stanford.edu>
// Creation Date: Thu Jul  5 12:07:35 PDT 2001
// Last Modified: Thu Jul  5 12:07:38 PDT 2001
// Filename:      ...sig/maint/code/Generator/AudioIn/AudioIn.cpp
// Web Address:   http://sig.sapp.org/src/sigSignal/AudioIn.cpp
// Documentation: http://sig.sapp.org/doc/classes/AudioIn
// Syntax:        C++ 
//
// Description:   buffered audio input
//

#include "AudioIn.h"


//////////////////////////////
//
// AudioIn::AudioIn --
//

AudioIn::AudioIn(void) {
   setName("AudioIn");
   brandname = GENERATOR;

   Output.setSize(4);
   Output.zero();
   framesize = audioin.getBufferSize();
   framei = framesize;
   audiobuffer = NULL;

}



//////////////////////////////
//
// AudioIn::~AudioIn --
//

AudioIn::~AudioIn() { 
   // do nothing
   audioin.close();
}



//////////////////////////////
//
// AudioIn::action --
//

void AudioIn::action(void) {
   if (framei >= framesize) {
      framei = 0;
      // getNextBuffer will block if new audio data is not yet available
      audiobuffer = audioin.getNextBuffer();
   }

   for (int i=0; i<getChannels(); i++) {
      Output[i] = ((sampleType)((short)audiobuffer[framei * 
            getChannels() + i])) / (long)0x8000; 
   }
   framei++;
}



//////////////////////////////
//
// AudioIn::extractSample16Bit -- reads a sample from the
//	soundfile.  The soundfile must be in 16 bit format or else
//	unreported errors will occur.  Also, you cannot use the
//	action function after calling this function since this
//	function does not keep track of the number of samples read
//	from the file.  This function is used only to extract the
//	integer sample values without converting them to floating
//	point samples.
//

short AudioIn::extractSample16Bit(void) {
   return 0;
}



//////////////////////////////
//
// AudioIn::open -- 
//

void AudioIn::open(void) {
   audioin.open16LSB(1, 44100);
}



//////////////////////////////
//
// AudioIn::open16LSB -- 
//

void AudioIn::open16LSB(int channels, int srate) {
   audioin.open16LSB(channels, srate);
}



//////////////////////////////
//
// AudioIn::close -- 
//

void AudioIn::close(void) {
   audioin.close();
}



//////////////////////////////
//
// AudioIn::getBitsPerSample --
//

int AudioIn::getBitsPerSample(void) {
   return 16;
}



//////////////////////////////
//
// AudioIn::getChannels --
//

int AudioIn::getChannels(void) {
   return 1;
}



//////////////////////////////
//
// AudioIn::output --
//     default: channel = 0
//

sampleType AudioIn::output(int channel) {
   return Output[channel];
}



//////////////////////////////
//
// AudioIn::printState --
//

void AudioIn::printState(void) {

}



//////////////////////////////
//
// AudioIn::reset --
//     default: sampleIndex = 0
//

void AudioIn::reset(int sampleIndex) {

}



// md5sum: 8980e8aa645ebdc95465bbcd4d8e85ec AudioIn.cpp [20010708]
